@@ -37,7 +37,7 @@
 from typing import List, Optional, Tuple, Union, cast
 
 import pytensor
-import pytensor.tensor as at
+import pytensor.tensor as pt
 
 from pytensor.graph.basic import Apply, Constant, Variable
 from pytensor.graph.fg import FunctionGraph
@@ -47,7 +47,7 @@ from pytensor.graph.rewriting.basic import (
     node_rewriter,
     pre_greedy_node_rewriter,
 )
-from pytensor.ifelse import ifelse
+from pytensor.ifelse import IfElse, ifelse
 from pytensor.scalar.basic import Switch
 from pytensor.tensor.basic import Join, MakeVector
 from pytensor.tensor.elemwise import Elemwise
@@ -69,18 +69,15 @@ from pytensor.tensor.type import TensorType
 from pytensor.tensor.type_other import NoneConst, NoneTypeT, SliceConstant, SliceType
 from pytensor.tensor.var import TensorVariable
 
-from pymc.logprob.abstract import (
-    MeasurableVariable,
-    _logprob,
-    assign_custom_measurable_outputs,
-    logprob,
-)
+from pymc.logprob.abstract import MeasurableVariable, _logprob, _logprob_helper
 from pymc.logprob.rewriting import (
     local_lift_DiracDelta,
     logprob_rewrites_db,
+    measurable_ir_rewrites_db,
     subtensor_ops,
 )
 from pymc.logprob.tensor import naive_bcast_rv_lift
+from pymc.logprob.utils import ignore_logprob, ignore_logprob_multiple_vars
 
 
 def is_newaxis(x):
@@ -141,7 +138,7 @@ def expand_indices(
         if not is_basic_idx(idx):
             s = shape_copy.pop(0)
 
-            idx = at.as_tensor(idx)
+            idx = pt.as_tensor(idx)
 
             if moved_subspace:
                 # The subspace generated by advanced indices appear as the
@@ -169,7 +166,7 @@ def expand_indices(
             if isinstance(idx, slice) or isinstance(getattr(idx, "type", None), SliceType):
                 idx = as_index_literal(idx)
                 idx_slice, _ = get_canonical_form_slice(idx, s)
-                idx = at.arange(idx_slice.start, idx_slice.stop, idx_slice.step)
+                idx = pt.arange(idx_slice.start, idx_slice.stop, idx_slice.step)
 
             if moved_subspace:
                 # Basic indices appear in the lower dimensions
@@ -202,7 +199,7 @@ def expand_indices(
 
         adv_indices.append(expanded_idx)
 
-    return cast(Tuple[TensorVariable], tuple(at.broadcast_arrays(*adv_indices)))
+    return cast(Tuple[TensorVariable], tuple(pt.broadcast_arrays(*adv_indices)))
 
 
 def rv_pull_down(x: TensorVariable, dont_touch_vars=None) -> TensorVariable:
@@ -267,7 +264,7 @@ def get_stack_mixture_vars(
         join_axis = joined_rvs.owner.inputs[0]
         # TODO: Support symbolic join axes. This will raise ValueError if it's not a constant
         (join_axis,) = constant_fold((join_axis,), raise_not_constant=False)
-        join_axis = at.as_tensor(join_axis, dtype="int64")
+        join_axis = pt.as_tensor(join_axis, dtype="int64")
 
         mixture_rvs = joined_rvs.owner.inputs[1:]
 
@@ -328,9 +325,7 @@ def mixture_replace(fgraph, node):
         # We create custom types for the mixture components and assign them
         # null `get_measurable_outputs` dispatches so that they aren't
         # erroneously encountered in places like `factorized_joint_logprob`.
-        new_node = assign_custom_measurable_outputs(component_rv.owner)
-        out_idx = component_rv.owner.outputs.index(component_rv)
-        new_comp_rv = new_node.outputs[out_idx]
+        new_comp_rv = ignore_logprob(component_rv)
         new_mixture_rvs.append(new_comp_rv)
 
     # Replace this sub-graph with a `MixtureRV`
@@ -379,9 +374,7 @@ def switch_mixture_replace(fgraph, node):
             and component_rv not in rv_map_feature.rv_values
         ):
             return None
-        new_node = assign_custom_measurable_outputs(component_rv.owner)
-        out_idx = component_rv.owner.outputs.index(component_rv)
-        new_comp_rv = new_node.outputs[out_idx]
+        new_comp_rv = ignore_logprob(component_rv)
         mixture_rvs.append(new_comp_rv)
 
     mix_op = MixtureRV(
@@ -437,10 +430,10 @@ def logprob_MixtureRV(
 
         bcast_indices = expand_indices(indices, original_shape)
 
-        logp_val = at.empty(bcast_indices[0].shape)
+        logp_val = pt.empty(bcast_indices[0].shape)
 
         for m, rv in enumerate(comp_rvs):
-            idx_m_on_axis = at.nonzero(at.eq(bcast_indices[join_axis_val], m))
+            idx_m_on_axis = pt.nonzero(pt.eq(bcast_indices[join_axis_val], m))
             m_indices = tuple(
                 v[idx_m_on_axis] for i, v in enumerate(bcast_indices) if i != join_axis_val
             )
@@ -452,8 +445,8 @@ def logprob_MixtureRV(
             # this intentional one-off?
             rv_m = rv_pull_down(rv[m_indices] if m_indices else rv)
             val_m = value[idx_m_on_axis]
-            logp_m = logprob(rv_m, val_m)
-            logp_val = at.set_subtensor(logp_val[idx_m_on_axis], logp_m)
+            logp_m = _logprob_helper(rv_m, val_m)
+            logp_val = pt.set_subtensor(logp_val[idx_m_on_axis], logp_m)
 
     else:
         # FIXME: This logprob implementation does not support mixing across distinct components,
@@ -466,17 +459,17 @@ def logprob_MixtureRV(
         join_axis_val = None if isinstance(join_axis.type, NoneTypeT) else join_axis.data
 
         if join_axis_val is not None:
-            value = at.expand_dims(value, axis=join_axis_val)
+            value = pt.expand_dims(value, axis=join_axis_val)
 
         logp_val = 0.0
         for i, comp_rv in enumerate(comp_rvs):
-            comp_logp = logprob(comp_rv, value)
+            comp_logp = _logprob_helper(comp_rv, value)
             if join_axis_val is not None:
-                comp_logp = at.squeeze(comp_logp, axis=join_axis_val)
+                comp_logp = pt.squeeze(comp_logp, axis=join_axis_val)
             logp_val += ifelse(
-                at.eq(indices[0], i),
+                pt.eq(indices[0], i),
                 comp_logp,
-                at.zeros_like(comp_logp),
+                pt.zeros_like(comp_logp),
             )
 
     return logp_val
@@ -491,3 +484,71 @@ logprob_rewrites_db.register(
     "basic",
     "mixture",
 )
+
+
+class MeasurableIfElse(IfElse):
+    """Measurable subclass of IfElse operator."""
+
+
+MeasurableVariable.register(MeasurableIfElse)
+
+
+@node_rewriter([IfElse])
+def find_measurable_ifelse_mixture(fgraph, node):
+    rv_map_feature = getattr(fgraph, "preserve_rv_mappings", None)
+
+    if rv_map_feature is None:
+        return None  # pragma: no cover
+
+    if isinstance(node.op, MeasurableIfElse):
+        return None
+
+    # Check if all components are unvalued measuarable variables
+    if_var, *base_rvs = node.inputs
+
+    if not all(
+        (
+            rv.owner is not None
+            and isinstance(rv.owner.op, MeasurableVariable)
+            and rv not in rv_map_feature.rv_values
+        )
+        for rv in base_rvs
+    ):
+        return None  # pragma: no cover
+
+    unmeasurable_base_rvs = ignore_logprob_multiple_vars(base_rvs, rv_map_feature.rv_values)
+
+    return MeasurableIfElse(n_outs=node.op.n_outs).make_node(if_var, *unmeasurable_base_rvs).outputs
+
+
+measurable_ir_rewrites_db.register(
+    "find_measurable_ifelse_mixture",
+    find_measurable_ifelse_mixture,
+    "basic",
+    "mixture",
+)
+
+
+@_logprob.register(MeasurableIfElse)
+def logprob_ifelse(op, values, if_var, *base_rvs, **kwargs):
+    """Compute the log-likelihood graph for an `IfElse`."""
+    from pymc.pytensorf import replace_rvs_by_values
+
+    assert len(values) * 2 == len(base_rvs)
+
+    rvs_to_values_then = {then_rv: value for then_rv, value in zip(base_rvs[: len(values)], values)}
+    rvs_to_values_else = {else_rv: value for else_rv, value in zip(base_rvs[len(values) :], values)}
+
+    logps_then = [
+        _logprob_helper(rv_then, value, **kwargs) for rv_then, value in rvs_to_values_then.items()
+    ]
+    logps_else = [
+        _logprob_helper(rv_else, value, **kwargs) for rv_else, value in rvs_to_values_else.items()
+    ]
+
+    # If the multiple variables depend on each other, we have to replace them
+    # by the respective values
+    logps_then = replace_rvs_by_values(logps_then, rvs_to_values=rvs_to_values_then)
+    logps_else = replace_rvs_by_values(logps_else, rvs_to_values=rvs_to_values_else)
+
+    return ifelse(if_var, logps_then, logps_else)
