@@ -22,7 +22,7 @@ from typing import Any, Callable, Dict, List, Optional, Sequence, Union
 import arviz as az
 import jax
 import numpy as np
-import pytensor.tensor as at
+import pytensor.tensor as pt
 
 from arviz.data.base import make_attrs
 from jax.experimental.maps import SerialLoop, xmap
@@ -96,7 +96,7 @@ def _replace_shared_variables(graph: List[TensorVariable]) -> List[TensorVariabl
             "be safely replaced."
         )
 
-    replacements = {var: at.constant(var.get_value(borrow=True)) for var in shared_variables}
+    replacements = {var: pt.constant(var.get_value(borrow=True)) for var in shared_variables}
 
     new_graph = clone_replace(graph, replace=replacements)
     return new_graph
