@@ -24,7 +24,8 @@ import pytest
 from numpy import random as nr
 from numpy import testing as npt
 from pytensor.compile.mode import Mode
-from pytensor.graph.basic import ancestors
+from pytensor.graph.basic import walk
+from pytensor.graph.op import HasInnerGraph
 from pytensor.graph.rewriting.basic import in2out
 from pytensor.tensor import TensorVariable
 from pytensor.tensor.random.op import RandomVariable
@@ -33,11 +34,11 @@ from scipy import stats as st
 
 import pymc as pm
 
-from pymc import Distribution, logcdf, logp
+from pymc.distributions.distribution import Distribution
 from pymc.distributions.shape_utils import change_dist_size
 from pymc.initial_point import make_initial_point_fn
-from pymc.logprob import joint_logp
-from pymc.logprob.abstract import icdf
+from pymc.logprob.abstract import MeasurableVariable
+from pymc.logprob.basic import icdf, joint_logp, logcdf, logp
 from pymc.logprob.utils import ParameterValueError
 from pymc.pytensorf import (
     compile_pymc,
@@ -525,6 +526,7 @@ def check_icdf(
     pymc_dist: Distribution,
     paramdomains: Dict[str, Domain],
     scipy_icdf: Callable,
+    skip_paramdomain_outside_edge_test=False,
     decimal: Optional[int] = None,
     n_samples: int = 100,
 ) -> None:
@@ -547,7 +549,7 @@ def check_icdf(
     paramdomains : Dictionary of Parameter : Domain pairs
         Supported domains of distribution parameters
     scipy_icdf : Scipy icdf method
-        Scipy icdf (ppp) method of equivalent pymc_dist distribution
+        Scipy icdf (ppf) method of equivalent pymc_dist distribution
     decimal : int, optional
         Level of precision with which pymc_dist and scipy_icdf are compared.
         Defaults to 6 for float64 and 3 for float32
@@ -556,6 +558,9 @@ def check_icdf(
         are compared between pymc and scipy methods. If n_samples is below the
         total number of combinations, a random subset is evaluated. Setting
         n_samples = -1, will return all possible combinations. Defaults to 100
+    skip_paradomain_outside_edge_test : Bool
+        Whether to run test 2., which checks that pymc distribution icdf
+        returns nan for invalid parameter values outside the supported domain edge
 
     """
     if decimal is None:
@@ -585,19 +590,20 @@ def check_icdf(
     valid_params = {param: paramdomain.vals[0] for param, paramdomain in paramdomains.items()}
     valid_params["q"] = valid_value
 
-    # Test pymc distribution raises ParameterValueError for parameters outside the
-    # supported domain edges (excluding edges)
-    invalid_params = find_invalid_scalar_params(paramdomains)
-    for invalid_param, invalid_edges in invalid_params.items():
-        for invalid_edge in invalid_edges:
-            if invalid_edge is None:
-                continue
+    if not skip_paramdomain_outside_edge_test:
+        # Test pymc distribution raises ParameterValueError for parameters outside the
+        # supported domain edges (excluding edges)
+        invalid_params = find_invalid_scalar_params(paramdomains)
+        for invalid_param, invalid_edges in invalid_params.items():
+            for invalid_edge in invalid_edges:
+                if invalid_edge is None:
+                    continue
 
-            point = valid_params.copy()
-            point[invalid_param] = invalid_edge
-            with pytest.raises(ParameterValueError):
-                pymc_icdf(**point)
-                pytest.fail(f"test_params={point}")
+                point = valid_params.copy()
+                point[invalid_param] = invalid_edge
+                with pytest.raises(ParameterValueError):
+                    pymc_icdf(**point)
+                    pytest.fail(f"test_params={point}")
 
     # Test that values below 0 or above 1 evaluate to nan
     invalid_values = find_invalid_scalar_params({"q": domain})["q"]
@@ -958,5 +964,18 @@ def seeded_numpy_distribution_builder(dist_name: str) -> Callable:
 
 
 def assert_no_rvs(var):
-    assert not any(isinstance(v.owner.op, RandomVariable) for v in ancestors([var]) if v.owner)
-    return var
+    """Assert that there are no `MeasurableVariable` nodes in a graph."""
+
+    def expand(r):
+        owner = r.owner
+        if owner:
+            inputs = list(reversed(owner.inputs))
+
+            if isinstance(owner.op, HasInnerGraph):
+                inputs += owner.op.inner_outputs
+
+            return inputs
+
+    for v in walk([var], expand, False):
+        if v.owner and isinstance(v.owner.op, (RandomVariable, MeasurableVariable)):
+            raise AssertionError(f"RV found in graph: {v}")
