@@ -444,6 +444,15 @@ class TestMatchesScipy:
             lambda q, lam: st.expon.ppf(q, loc=0, scale=1 / lam),
         )
 
+    def test_exponential_wrong_arguments(self):
+        msg = "Incompatible parametrization. Can't specify both lam and scale"
+        with pytest.raises(ValueError, match=msg):
+            pm.Exponential.dist(lam=0.5, scale=5)
+
+        msg = "Incompatible parametrization. Must specify either lam or scale"
+        with pytest.raises(ValueError, match=msg):
+            pm.Exponential.dist()
+
     def test_laplace(self):
         check_logp(
             pm.Laplace,
@@ -457,6 +466,7 @@ class TestMatchesScipy:
             {"mu": R, "b": Rplus},
             lambda value, mu, b: st.laplace.logcdf(value, mu, b),
         )
+        check_icdf(pm.Laplace, {"mu": R, "b": Rplus}, lambda q, mu, b: st.laplace.ppf(q, mu, b))
 
     def test_laplace_asymmetric(self):
         check_logp(
@@ -633,6 +643,11 @@ class TestMatchesScipy:
             {"alpha": Rplusbig, "m": Rplusbig},
             lambda value, alpha, m: st.pareto.logcdf(value, alpha, scale=m),
         )
+        check_icdf(
+            pm.Pareto,
+            {"alpha": Rplusbig, "m": Rplusbig},
+            lambda q, alpha, m: st.pareto.ppf(q, alpha, scale=m),
+        )
 
     @pytest.mark.skipif(
         condition=(pytensor.config.floatX == "float32"),
@@ -2091,6 +2106,13 @@ class TestExponential(BaseTestDistributionRandom):
     ]
 
 
+class TestExponentialScale(BaseTestDistributionRandom):
+    pymc_dist = pm.Exponential
+    pymc_dist_params = {"scale": 5.0}
+    expected_rv_op_params = {"mu": pymc_dist_params["scale"]}
+    checks_to_run = ["check_pymc_params_match_rv_op"]
+
+
 class TestCauchy(BaseTestDistributionRandom):
     pymc_dist = pm.Cauchy
     pymc_dist_params = {"alpha": 2.0, "beta": 5.0}
