@@ -11,6 +11,7 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
+import sys
 import warnings
 
 import cloudpickle
@@ -22,6 +23,7 @@ import pytensor.tensor as pt
 import pytest
 import scipy.stats as st
 
+from pytensor import scan
 from pytensor.tensor import TensorVariable
 
 import pymc as pm
@@ -50,8 +52,15 @@ from pymc.exceptions import BlockModelAccessError
 from pymc.logprob.abstract import get_measurable_outputs
 from pymc.logprob.basic import logcdf, logp
 from pymc.model import Deterministic, Model
+from pymc.pytensorf import collect_default_updates
 from pymc.sampling import draw, sample
-from pymc.testing import assert_moment_is_expected
+from pymc.testing import (
+    BaseTestDistributionRandom,
+    I,
+    assert_moment_is_expected,
+    check_logcdf,
+    check_logp,
+)
 from pymc.util import _FutureWarningValidatingScratchpad
 
 
@@ -516,6 +525,48 @@ class TestCustomSymbolicDist:
         # New API is fine
         pm.CustomDist.dist(dist=old_random, class_name="custom_dist")
 
+    def test_scan(self):
+        def trw(nu, sigma, steps, size):
+            def step(xtm1, nu, sigma):
+                x = pm.StudentT.dist(nu=nu, mu=xtm1, sigma=sigma, shape=size)
+                return x, collect_default_updates([x])
+
+            xs, _ = scan(
+                fn=step,
+                outputs_info=pt.zeros(size),
+                non_sequences=[nu, sigma],
+                n_steps=steps,
+            )
+
+            # Logprob inference cannot be derived yet  https://github.com/pymc-devs/pymc/issues/6360
+            # xs = swapaxes(xs, 0, -1)
+
+            return xs
+
+        nu = 4
+        sigma = 0.7
+        steps = 99
+        batch_size = 3
+        x = CustomDist.dist(nu, sigma, steps, dist=trw, size=batch_size)
+
+        x_draw = pm.draw(x, random_seed=1)
+        assert x_draw.shape == (steps, batch_size)
+        np.testing.assert_allclose(pm.draw(x, random_seed=1), x_draw)
+        assert not np.any(pm.draw(x, random_seed=2) == x_draw)
+
+        ref_dist = pm.RandomWalk.dist(
+            init_dist=pm.Flat.dist(),
+            innovation_dist=pm.StudentT.dist(nu=nu, sigma=sigma),
+            steps=steps,
+            size=(batch_size,),
+        )
+        ref_val = pt.concatenate([np.zeros((1, batch_size)), x_draw]).T
+
+        np.testing.assert_allclose(
+            pm.logp(x, x_draw).eval().sum(0),
+            pm.logp(ref_dist, ref_val).eval(),
+        )
+
 
 class TestSymbolicRandomVariable:
     def test_inline(self):
@@ -600,3 +651,52 @@ def test_distribution_op_registered():
     """Test that returned Ops are registered as virtual subclasses of the respective PyMC distributions."""
     assert isinstance(Normal.dist().owner.op, Normal)
     assert isinstance(Censored.dist(Normal.dist(), lower=None, upper=None).owner.op, Censored)
+
+
+class TestDiracDelta:
+    def test_logp(self):
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", "divide by zero encountered in log", RuntimeWarning)
+            check_logp(pm.DiracDelta, I, {"c": I}, lambda value, c: np.log(c == value))
+            check_logcdf(pm.DiracDelta, I, {"c": I}, lambda value, c: np.log(value >= c))
+
+        @pytest.mark.parametrize(
+            "c, size, expected",
+            [
+                (1, None, 1),
+                (1, 5, np.full(5, 1)),
+                (np.arange(1, 6), None, np.arange(1, 6)),
+            ],
+        )
+        def test_moment(self, c, size, expected):
+            with pm.Model() as model:
+                pm.DiracDelta("x", c=c, size=size)
+            assert_moment_is_expected(model, expected)
+
+    class TestDiracDelta(BaseTestDistributionRandom):
+        def diracdelta_rng_fn(self, size, c):
+            if size is None:
+                return c
+            return np.full(size, c)
+
+        pymc_dist = pm.DiracDelta
+        pymc_dist_params = {"c": 3}
+        expected_rv_op_params = {"c": 3}
+        reference_dist_params = {"c": 3}
+        reference_dist = lambda self: self.diracdelta_rng_fn
+        checks_to_run = [
+            "check_pymc_params_match_rv_op",
+            "check_pymc_draws_match_reference",
+            "check_rv_size",
+        ]
+
+        @pytest.mark.parametrize("floatX", ["float32", "float64"])
+        @pytest.mark.xfail(
+            sys.platform == "win32", reason="https://github.com/pytensor-devs/pytensor/issues/871"
+        )
+        def test_dtype(self, floatX):
+            with pytensor.config.change_flags(floatX=floatX):
+                assert pm.DiracDelta.dist(2**4).dtype == "int8"
+                assert pm.DiracDelta.dist(2**16).dtype == "int32"
+                assert pm.DiracDelta.dist(2**32).dtype == "int64"
+                assert pm.DiracDelta.dist(2.0).dtype == floatX
