@@ -95,6 +95,19 @@ class TestCovAdd:
         with pytest.raises(ValueError, match=r"cannot combine"):
             cov = M + pm.gp.cov.ExpQuad(1, 1.0)
 
+    def test_rightadd_whitenoise(self):
+        X = np.linspace(0, 1, 10)[:, None]
+        with pm.Model() as model:
+            cov1 = pm.gp.cov.ExpQuad(1, 0.1)
+            cov2 = pm.gp.cov.WhiteNoise(sigma=1)
+            cov = cov1 + cov2
+        K = cov(X).eval()
+        npt.assert_allclose(K[0, 1], 0.53940, atol=1e-3)
+        npt.assert_allclose(K[0, 0], 2, atol=1e-3)
+        # check diagonal
+        Kd = cov(X, diag=True).eval()
+        npt.assert_allclose(np.diag(K), Kd, atol=1e-5)
+
 
 class TestCovProd:
     def test_symprod_cov(self):
