@@ -49,9 +49,13 @@ from pytensor.scan import scan
 
 from pymc.distributions.transforms import _default_transform, log, logodds
 from pymc.logprob.abstract import MeasurableVariable, _get_measurable_outputs, _logprob
-from pymc.logprob.basic import factorized_joint_logprob
+from pymc.logprob.basic import factorized_joint_logprob, logp
 from pymc.logprob.transforms import (
     ChainedTransform,
+    CoshTransform,
+    ErfcTransform,
+    ErfcxTransform,
+    ErfTransform,
     ExpTransform,
     IntervalTransform,
     LocTransform,
@@ -59,12 +63,13 @@ from pymc.logprob.transforms import (
     LogTransform,
     RVTransform,
     ScaleTransform,
+    SinhTransform,
+    TanhTransform,
     TransformValuesMapping,
     TransformValuesRewrite,
     transformed_variable,
 )
 from pymc.testing import assert_no_rvs
-from tests.logprob.utils import joint_logprob
 
 
 class DirichletScipyDist:
@@ -235,11 +240,14 @@ def test_transformed_logprob(at_dist, dist_params, sp_dist, size):
 
     transform = _default_transform(a.owner.op, a)
     transform_rewrite = TransformValuesRewrite({a_value_var: transform})
-    res = joint_logprob({a: a_value_var, b: b_value_var}, extra_rewrites=transform_rewrite)
+    res = factorized_joint_logprob(
+        {a: a_value_var, b: b_value_var}, extra_rewrites=transform_rewrite
+    )
+    res_combined = pt.sum([pt.sum(factor) for factor in res.values()])
 
     test_val_rng = np.random.RandomState(3238)
 
-    logp_vals_fn = pytensor.function([a_value_var, b_value_var], res)
+    logp_vals_fn = pytensor.function([a_value_var, b_value_var], res_combined)
 
     a_forward_fn = pytensor.function([a_value_var], transform.forward(a_value_var, *a.owner.inputs))
     a_backward_fn = pytensor.function(
@@ -308,12 +316,13 @@ def test_simple_transformed_logprob_nojac(use_jacobian):
     x_vv.name = "x"
 
     transform_rewrite = TransformValuesRewrite({x_vv: log})
-    tr_logp = joint_logprob(
+    tr_logp = factorized_joint_logprob(
         {X_rv: x_vv}, extra_rewrites=transform_rewrite, use_jacobian=use_jacobian
     )
+    tr_logp_combined = pt.sum([pt.sum(factor) for factor in tr_logp.values()])
 
     assert np.isclose(
-        tr_logp.eval({x_vv: np.log(2.5)}),
+        tr_logp_combined.eval({x_vv: np.log(2.5)}),
         sp.stats.halfnorm(0, 3).logpdf(2.5) + (np.log(2.5) if use_jacobian else 0.0),
     )
 
@@ -327,6 +336,7 @@ def test_fallback_log_jac_det(ndim):
 
     class SquareTransform(RVTransform):
         name = "square"
+        ndim_supp = ndim
 
         def forward(self, value, *inputs):
             return pt.power(value, 2)
@@ -336,13 +346,31 @@ def test_fallback_log_jac_det(ndim):
 
     square_tr = SquareTransform()
 
-    value = pt.TensorType("float64", (None,) * ndim)("value")
+    value = pt.vector("value")
     value_tr = square_tr.forward(value)
     log_jac_det = square_tr.log_jac_det(value_tr)
 
-    test_value = np.full((2,) * ndim, 3)
-    expected_log_jac_det = -np.log(6) * test_value.size
-    assert np.isclose(log_jac_det.eval({value: test_value}), expected_log_jac_det)
+    test_value = np.r_[3, 4]
+    expected_log_jac_det = -np.log(2 * test_value)
+    if ndim == 1:
+        expected_log_jac_det = expected_log_jac_det.sum()
+    np.testing.assert_array_equal(log_jac_det.eval({value: test_value}), expected_log_jac_det)
+
+
+@pytest.mark.parametrize("ndim", (None, 2))
+def test_fallback_log_jac_det_undefined_ndim(ndim):
+    class SquareTransform(RVTransform):
+        name = "square"
+        ndim_supp = ndim
+
+        def forward(self, value, *inputs):
+            return pt.power(value, 2)
+
+        def backward(self, value, *inputs):
+            return pt.sqrt(value)
+
+    with pytest.raises(NotImplementedError, match=r"only implemented for ndim_supp in \(0, 1\)"):
+        SquareTransform().log_jac_det(0)
 
 
 def test_hierarchical_uniform_transform():
@@ -366,13 +394,14 @@ def test_hierarchical_uniform_transform():
             x: _default_transform(x_rv.owner.op, x_rv),
         }
     )
-    logp = joint_logprob(
+    logp = factorized_joint_logprob(
         {lower_rv: lower, upper_rv: upper, x_rv: x},
         extra_rewrites=transform_rewrite,
     )
+    logp_combined = pt.sum([pt.sum(factor) for factor in logp.values()])
 
-    assert_no_rvs(logp)
-    assert not np.isinf(logp.eval({lower: -10, upper: 20, x: -20}))
+    assert_no_rvs(logp_combined)
+    assert not np.isinf(logp_combined.eval({lower: -10, upper: 20, x: -20}))
 
 
 def test_nondefault_transforms():
@@ -392,10 +421,11 @@ def test_nondefault_transforms():
         }
     )
 
-    logp = joint_logprob(
+    logp = factorized_joint_logprob(
         {loc_rv: loc, scale_rv: scale, x_rv: x},
         extra_rewrites=transform_rewrite,
     )
+    logp_combined = pt.sum([pt.sum(factor) for factor in logp.values()])
 
     # Check numerical evaluation matches with expected transforms
     loc_val = 0
@@ -413,7 +443,7 @@ def test_nondefault_transforms():
     exp_logp += x_val_tr  # log log_jac_det
 
     assert np.isclose(
-        logp.eval({loc: loc_val, scale: scale_val_tr, x: x_val_tr}),
+        logp_combined.eval({loc: loc_val, scale: scale_val_tr, x: x_val_tr}),
         exp_logp,
     )
 
@@ -429,13 +459,14 @@ def test_default_transform_multiout():
 
     transform_rewrite = TransformValuesRewrite({x: None})
 
-    logp = joint_logprob(
+    logp = factorized_joint_logprob(
         {x_rv: x},
         extra_rewrites=transform_rewrite,
     )
+    logp_combined = pt.sum([pt.sum(factor) for factor in logp.values()])
 
     assert np.isclose(
-        logp.eval({x: 1}),
+        logp_combined.eval({x: 1}),
         sp.stats.norm(0, 1).logpdf(1),
     )
 
@@ -481,7 +512,8 @@ def test_nondefault_transform_multiout(transform_x, transform_y, multiout_measur
         }
     )
 
-    logp = joint_logprob({x: x_vv, y: y_vv}, extra_rewrites=transform_rewrite)
+    logp = factorized_joint_logprob({x: x_vv, y: y_vv}, extra_rewrites=transform_rewrite)
+    logp_combined = pt.sum([pt.sum(factor) for factor in logp.values()])
 
     x_vv_test = np.random.normal()
     y_vv_test = np.abs(np.random.normal())
@@ -497,7 +529,9 @@ def test_nondefault_transform_multiout(transform_x, transform_y, multiout_measur
     else:
         expected_logp += np.log(y_vv_test) + 2 - np.log(y_vv_test)
 
-    np.testing.assert_almost_equal(logp.eval({x_vv: x_vv_test, y_vv: y_vv_test}), expected_logp)
+    np.testing.assert_almost_equal(
+        logp_combined.eval({x_vv: x_vv_test, y_vv: y_vv_test}), expected_logp
+    )
 
 
 def test_TransformValuesMapping():
@@ -527,6 +561,7 @@ def test_original_values_output_dict():
     assert p_vv in logp_dict
 
 
+@pytest.mark.filterwarnings("error")
 def test_mixture_transform():
     """Make sure that non-`RandomVariable` `MeasurableVariable`s can be transformed.
 
@@ -547,31 +582,29 @@ def test_mixture_transform():
     y_vv = Y_rv.clone()
     y_vv.name = "y"
 
-    logp_no_trans = joint_logprob(
+    logp_no_trans = factorized_joint_logprob(
         {Y_rv: y_vv, I_rv: i_vv},
     )
+    logp_no_trans_comb = pt.sum([pt.sum(factor) for factor in logp_no_trans.values()])
 
     transform_rewrite = TransformValuesRewrite({y_vv: LogTransform()})
 
-    with pytest.warns(None) as record:
-        # This shouldn't raise any warnings
-        logp_trans = joint_logprob(
-            {Y_rv: y_vv, I_rv: i_vv},
-            extra_rewrites=transform_rewrite,
-            use_jacobian=False,
-        )
-
-    assert not record.list
+    logp_trans = factorized_joint_logprob(
+        {Y_rv: y_vv, I_rv: i_vv},
+        extra_rewrites=transform_rewrite,
+        use_jacobian=False,
+    )
+    logp_trans_combined = pt.sum([pt.sum(factor) for factor in logp_trans.values()])
 
     # The untransformed graph should be the same as the transformed graph after
     # replacing the `Y_rv` value variable with a transformed version of itself
-    logp_nt_fg = FunctionGraph(outputs=[logp_no_trans], clone=False)
-    y_trans = transformed_variable(pt.exp(y_vv), y_vv)
+    logp_nt_fg = FunctionGraph(outputs=[logp_no_trans_comb], clone=False)
+    y_trans = pt.exp(y_vv)
     y_trans.name = "y_log"
     logp_nt_fg.replace(y_vv, y_trans)
     logp_nt = logp_nt_fg.outputs[0]
 
-    assert equal_computations([logp_nt], [logp_trans])
+    assert equal_computations([logp_nt], [logp_trans_combined])
 
 
 def test_invalid_interval_transform():
@@ -637,8 +670,8 @@ def test_exp_transform_rv():
     y_rv.name = "y"
 
     y_vv = y_rv.clone()
-    logp = joint_logprob({y_rv: y_vv}, sum=False)
-    logp_fn = pytensor.function([y_vv], logp)
+    logprob = logp(y_rv, y_vv)
+    logp_fn = pytensor.function([y_vv], logprob)
 
     y_val = [-2.0, 0.1, 0.3]
     np.testing.assert_allclose(
@@ -653,8 +686,8 @@ def test_log_transform_rv():
     y_rv.name = "y"
 
     y_vv = y_rv.clone()
-    logp = joint_logprob({y_rv: y_vv}, sum=False)
-    logp_fn = pytensor.function([y_vv], logp)
+    logprob = logp(y_rv, y_vv)
+    logp_fn = pytensor.function([y_vv], logprob)
 
     y_val = [0.1, 0.3]
     np.testing.assert_allclose(
@@ -680,9 +713,9 @@ def test_loc_transform_rv(rv_size, loc_type, addition):
     y_rv.name = "y"
     y_vv = y_rv.clone()
 
-    logp = joint_logprob({y_rv: y_vv}, sum=False)
-    assert_no_rvs(logp)
-    logp_fn = pytensor.function([loc, y_vv], logp)
+    logprob = logp(y_rv, y_vv)
+    assert_no_rvs(logprob)
+    logp_fn = pytensor.function([loc, y_vv], logprob)
 
     loc_test_val = np.full(rv_size, 4.0)
     y_test_val = np.full(rv_size, 1.0)
@@ -710,9 +743,9 @@ def test_scale_transform_rv(rv_size, scale_type, product):
     y_rv.name = "y"
     y_vv = y_rv.clone()
 
-    logp = joint_logprob({y_rv: y_vv}, sum=False)
-    assert_no_rvs(logp)
-    logp_fn = pytensor.function([scale, y_vv], logp)
+    logprob = logp(y_rv, y_vv)
+    assert_no_rvs(logprob)
+    logp_fn = pytensor.function([scale, y_vv], logprob)
 
     scale_test_val = np.full(rv_size, 4.0)
     y_test_val = np.full(rv_size, 1.0)
@@ -730,9 +763,10 @@ def test_transformed_rv_and_value():
 
     transform_rewrite = TransformValuesRewrite({y_vv: LogTransform()})
 
-    logp = joint_logprob({y_rv: y_vv}, extra_rewrites=transform_rewrite)
-    assert_no_rvs(logp)
-    logp_fn = pytensor.function([y_vv], logp)
+    logp = factorized_joint_logprob({y_rv: y_vv}, extra_rewrites=transform_rewrite)
+    logp_combined = pt.sum([pt.sum(factor) for factor in logp.values()])
+    assert_no_rvs(logp_combined)
+    logp_fn = pytensor.function([y_vv], logp_combined)
 
     y_test_val = -5
 
@@ -750,7 +784,7 @@ def test_loc_transform_multiple_rvs_fails1():
     y = y_rv.clone()
 
     with pytest.raises(RuntimeError, match="could not be derived"):
-        joint_logprob({y_rv: y})
+        factorized_joint_logprob({y_rv: y})
 
 
 def test_nested_loc_transform_multiple_rvs_fails2():
@@ -761,19 +795,19 @@ def test_nested_loc_transform_multiple_rvs_fails2():
     y = y_rv.clone()
 
     with pytest.raises(RuntimeError, match="could not be derived"):
-        joint_logprob({y_rv: y})
+        factorized_joint_logprob({y_rv: y})
 
 
 def test_discrete_rv_unary_transform_fails():
     y_rv = pt.exp(pt.random.poisson(1))
     with pytest.raises(RuntimeError, match="could not be derived"):
-        joint_logprob({y_rv: y_rv.clone()})
+        factorized_joint_logprob({y_rv: y_rv.clone()})
 
 
 def test_discrete_rv_multinary_transform_fails():
     y_rv = 5 + pt.random.poisson(1)
     with pytest.raises(RuntimeError, match="could not be derived"):
-        joint_logprob({y_rv: y_rv.clone()})
+        factorized_joint_logprob({y_rv: y_rv.clone()})
 
 
 @pytest.mark.xfail(reason="Check not implemented yet")
@@ -784,8 +818,8 @@ def test_invalid_broadcasted_transform_rv_fails():
     y_vv = y_rv.clone()
 
     # This logp derivation should fail or count only once the values that are broadcasted
-    logp = joint_logprob({y_rv: y_vv}, sum=False)
-    assert logp.eval({y_vv: [0, 0, 0, 0], loc: [0, 0, 0, 0]}).shape == ()
+    logprob = logp(y_rv, y_vv)
+    assert logprob.eval({y_vv: [0, 0, 0, 0], loc: [0, 0, 0, 0]}).shape == ()
 
 
 @pytest.mark.parametrize("numerator", (1.0, 2.0))
@@ -796,7 +830,7 @@ def test_reciprocal_rv_transform(numerator):
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
-    x_logp_fn = pytensor.function([x_vv], joint_logprob({x_rv: x_vv}, sum=False))
+    x_logp_fn = pytensor.function([x_vv], logp(x_rv, x_vv))
 
     x_test_val = np.r_[-0.5, 1.5]
     assert np.allclose(
@@ -811,7 +845,7 @@ def test_sqr_transform():
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
-    x_logp_fn = pytensor.function([x_vv], joint_logprob({x_rv: x_vv}, sum=False))
+    x_logp_fn = pytensor.function([x_vv], logp(x_rv, x_vv))
 
     x_test_val = np.r_[-0.5, 0.5, 1, 2.5]
     assert np.allclose(
@@ -826,7 +860,7 @@ def test_sqrt_transform():
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
-    x_logp_fn = pytensor.function([x_vv], joint_logprob({x_rv: x_vv}, sum=False))
+    x_logp_fn = pytensor.function([x_vv], logp(x_rv, x_vv))
 
     x_test_val = np.r_[-2.5, 0.5, 1, 2.5]
     assert np.allclose(
@@ -842,7 +876,7 @@ def test_negative_value_odd_power_transform(power):
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
-    x_logp_fn = pytensor.function([x_vv], joint_logprob({x_rv: x_vv}, sum=False))
+    x_logp_fn = pytensor.function([x_vv], logp(x_rv, x_vv))
 
     assert np.isfinite(x_logp_fn(1))
     assert np.isfinite(x_logp_fn(-1))
@@ -855,7 +889,7 @@ def test_negative_value_even_power_transform(power):
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
-    x_logp_fn = pytensor.function([x_vv], joint_logprob({x_rv: x_vv}, sum=False))
+    x_logp_fn = pytensor.function([x_vv], logp(x_rv, x_vv))
 
     assert np.isfinite(x_logp_fn(1))
     assert np.isneginf(x_logp_fn(-1))
@@ -868,7 +902,7 @@ def test_negative_value_frac_power_transform(power):
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
-    x_logp_fn = pytensor.function([x_vv], joint_logprob({x_rv: x_vv}, sum=False))
+    x_logp_fn = pytensor.function([x_vv], logp(x_rv, x_vv))
 
     assert np.isfinite(x_logp_fn(2.5))
     assert np.isneginf(x_logp_fn(-2.5))
@@ -881,8 +915,8 @@ def test_absolute_transform(test_val):
 
     x_vv = x_rv.clone()
     y_vv = y_rv.clone()
-    x_logp_fn = pytensor.function([x_vv], joint_logprob({x_rv: x_vv}, sum=False))
-    y_logp_fn = pytensor.function([y_vv], joint_logprob({y_rv: y_vv}, sum=False))
+    x_logp_fn = pytensor.function([x_vv], logp(x_rv, x_vv))
+    y_logp_fn = pytensor.function([y_vv], logp(y_rv, y_vv))
 
     assert np.allclose(x_logp_fn(test_val), y_logp_fn(test_val))
 
@@ -892,7 +926,7 @@ def test_negated_rv_transform():
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
-    x_logp_fn = pytensor.function([x_vv], joint_logprob({x_rv: x_vv}))
+    x_logp_fn = pytensor.function([x_vv], pt.sum(logp(x_rv, x_vv)))
 
     assert np.isclose(x_logp_fn(-1.5), sp.stats.halfnorm.logpdf(1.5))
 
@@ -903,7 +937,7 @@ def test_subtracted_rv_transform():
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
-    x_logp_fn = pytensor.function([x_vv], joint_logprob({x_rv: x_vv}))
+    x_logp_fn = pytensor.function([x_vv], pt.sum(logp(x_rv, x_vv)))
 
     assert np.isclose(x_logp_fn(7.3), sp.stats.norm.logpdf(5.0 - 7.3, 1.0))
 
@@ -989,3 +1023,57 @@ def test_multivariate_transform(shift, scale):
             scale_mat @ cov @ scale_mat.T,
         ),
     )
+
+
+@pytest.mark.parametrize(
+    "pt_transform, transform",
+    [
+        (pt.erf, ErfTransform()),
+        (pt.erfc, ErfcTransform()),
+        (pt.erfcx, ErfcxTransform()),
+        (pt.sinh, SinhTransform()),
+        (pt.cosh, CoshTransform()),
+        (pt.tanh, TanhTransform()),
+    ],
+)
+def test_erf_logp(pt_transform, transform):
+    base_rv = pt.random.normal(
+        0.5, 1, name="base_rv"
+    )  # Something not centered around 0 is usually better
+    rv = pt_transform(base_rv)
+
+    vv = rv.clone()
+    rv_logp = logp(rv, vv)
+
+    expected_logp = logp(base_rv, transform.backward(vv)) + transform.log_jac_det(vv)
+
+    vv_test = np.array(0.25)  # Arbitrary test value
+    np.testing.assert_almost_equal(
+        rv_logp.eval({vv: vv_test}), np.nan_to_num(expected_logp.eval({vv: vv_test}), nan=-np.inf)
+    )
+
+
+from pymc.testing import Rplusbig, Vector
+from tests.distributions.test_transform import check_jacobian_det
+
+
+@pytest.mark.parametrize(
+    "transform",
+    [
+        ErfTransform(),
+        ErfcTransform(),
+        ErfcxTransform(),
+        SinhTransform(),
+        CoshTransform(),
+        TanhTransform(),
+    ],
+)
+def test_check_jac_det(transform):
+    check_jacobian_det(
+        transform,
+        Vector(Rplusbig, 2),
+        pt.dvector,
+        [0.1, 0.1],
+        elemwise=True,
+        rv_var=pt.random.normal(0.5, 1, name="base_rv"),
+    )
